@@ -4,7 +4,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 our $DATE = '2014-06-24'; # DATE
 
 1;
@@ -22,7 +22,7 @@ App::PMUtils - Command line to manipulate Perl module files
 
 =head1 VERSION
 
-This document describes version 0.02 of App::PMUtils (from Perl distribution App-PMUtils), released on 2014-06-24.
+This document describes version 0.03 of App::PMUtils (from Perl distribution App-PMUtils), released on 2014-06-24.
 
 =head1 SYNOPSIS
 
@@ -34,6 +34,8 @@ This distribution provides the following command-line utilities:
  pmless
  pmedit
  pmcost
+ pmdoc
+ pmman
 
 =head1 HOMEPAGE
 
